media-vidio/vidify(-audiosync) net-misc/lyricwikia: treeclean

Signed-off-by: Florian Schmaus <flow@gentoo.org>
This commit is contained in:
Florian Schmaus
2025-02-08 11:01:56 +01:00
parent 69c9df8eaa
commit f09b22cba5
14 changed files with 0 additions and 444 deletions

View File

@@ -1 +0,0 @@
DIST vidify-audiosync-0.3.0.tar.gz 61854604 BLAKE2B d6ffb65152044932d1e0a57d573c14d9378815c714d680d7a446e54ba6f4e572346165eb3c0f9b7793eb03fc5d0e1f2a07a8d0a64c76971892ad5c5d0ea4fc50 SHA512 b245dea22353acae94de1f0c0465d5d1040d19f372702eba52790bf6ace861ede497562957178aa40e7a9c30ba47061b9e23761900cc18a6c7b1e3579db6ccd0

View File

@@ -1,17 +0,0 @@
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE pkgmetadata SYSTEM "https://www.gentoo.org/dtd/metadata.dtd">
<pkgmetadata>
<maintainer type="person">
<email>nowa@gentoo.org</email>
<name>Nowa Ammerlaan</name>
</maintainer>
<upstream>
<maintainer>
<email>marioortizmanero@gmail.com</email>
<name>Mario Ortiz Manero</name>
</maintainer>
<remote-id type="github">vidify/old-audiosync</remote-id>
<bugs-to>https://github.com/vidify/old-audiosync/issues</bugs-to>
</upstream>
</pkgmetadata>

View File

@@ -1,47 +0,0 @@
# Copyright 1999-2024 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2
EAPI=8
PYTHON_COMPAT=( python3_{10..12} )
DISTUTILS_USE_PEP517=setuptools
DISTUTILS_EXT=1
inherit distutils-r1
DESCRIPTION="Audio synchronization feature for vidify"
HOMEPAGE="https://vidify.org"
SRC_URI="https://github.com/vidify/old-audiosync/archive/v${PV}.tar.gz -> ${P}.tar.gz"
LICENSE="LGPL-3"
SLOT="0"
KEYWORDS="~amd64"
IUSE="debug test"
RESTRICT="!test? ( test )"
RDEPEND="
media-libs/libpulse
media-video/ffmpeg[openssl]
media-video/vidify[${PYTHON_USEDEP}]
sci-libs/fftw
debug? ( sci-visualization/gnuplot )
"
BDEPEND="test? ( dev-build/cmake )"
S="${WORKDIR}/old-audiosync-${PV}"
python_prepare_all() {
if use debug; then
sed -i -e "/defines.append(('DEBUG', '1'))/s/^# *//" setup.py || die
fi
distutils-r1_python_prepare_all
}
python_test() {
mkdir "test_build_${EPYTHON}" || die
cd "test_build_${EPYTHON}" || die
cmake .. -DBUILD_TESTING=YES || die
emake
emake test
cd .. || die
}

View File

@@ -1 +0,0 @@
DIST vidify-2.2.6.tar.gz 2906511 BLAKE2B 3df48ca57e102f664852e2fc2abeb3d19427673e1fec5144a8c0afda112a0f3b281b18db43b4326244266d6e9dfbcb2443319ddad3f864098a61bd1e3c966307 SHA512 15487ee9dcbe647b2b287bd2eb3c09962b557320313a9a3885fb3c0d6af945909531111d5297c1a5fb5b451af5df6fd968b3953bbf79af113980ed368a5674b5

View File

@@ -1,16 +0,0 @@
diff --git a/vidify/player/vlc.py b/vidify/player/vlc.py
index a7c9ec0..cb50f89 100644
--- a/vidify/player/vlc.py
+++ b/vidify/player/vlc.py
@@ -75,9 +75,9 @@ class VLCPlayer(PlayerBase):
def start_video(self, media: str, is_playing: bool = True) -> None:
logging.info("Starting new video")
if CURRENT_PLATFORM in (Platform.LINUX, Platform.BSD):
- self._player.set_xwindow(self.winId())
+ self._player.set_xwindow(int(self.winId()))
elif CURRENT_PLATFORM == Platform.WINDOWS:
- self._player.set_hwnd(self.winId())
+ self._player.set_hwnd(int(self.winId()))
elif CURRENT_PLATFORM == Platform.MACOS:
self._player.set_nsobject(int(self.winId()))

View File

@@ -1,122 +0,0 @@
diff --git a/README.md b/README.md
index c4ea164..51e65e6 100644
--- a/README.md
+++ b/README.md
@@ -79,7 +79,7 @@ Audiosync is only available on Linux for now. It's strongly recommended to use M
* FFTW: `libfftw3` on Debian-based distros.
* ffmpeg: `ffmpeg` on most repositories. It must be available on your path.
* pulseaudio: `pulseaudio`, pre-installed on most repos.
-* youtube-dl: this is installed by default with Vidify, but make sure it's available on your path.
+* yt-dlp: this is installed by default with Vidify, but make sure it's available on your path.
It's also available as [`vidify-audiosync`](https://aur.archlinux.org/packages/vidify-audiosync) on the AUR, and it comes pre-installed in the binaries.
diff --git a/dev/build_requires.txt b/dev/build_requires.txt
index ed682fd..a8bbc30 100644
--- a/dev/build_requires.txt
+++ b/dev/build_requires.txt
@@ -14,5 +14,5 @@ QtPy
SwSpotify>=1.1.1; platform_system == "Windows" or platform_system == "Darwin"
tekore < 2.0
vidify-audiosync == 0.2.*
-youtube-dl
+yt-dlp
zeroconf
diff --git a/dev/snapcraft.yaml b/dev/snapcraft.yaml
index a5446de..00d2aae 100644
--- a/dev/snapcraft.yaml
+++ b/dev/snapcraft.yaml
@@ -22,7 +22,7 @@ parts:
- python3-pyqt5
- python3-appdirs
- python3-pydbus
- - youtube-dl
+ - yt-dlp
# Mpv is used by default because it's lighter and works better
# with the audiosync feature.
- libmpv-dev
diff --git a/setup.py b/setup.py
index 3fdb656..9b1c093 100644
--- a/setup.py
+++ b/setup.py
@@ -19,7 +19,7 @@ install_deps = [
# Base package
'QtPy',
'lyricwikia',
- 'youtube-dl',
+ 'yt-dlp',
'appdirs',
'qdarkstyle',
'dataclasses; python_version<"3.7"',
diff --git a/vidify/player/mpv.py b/vidify/player/mpv.py
index 4b92571..68bd1a5 100644
--- a/vidify/player/mpv.py
+++ b/vidify/player/mpv.py
@@ -30,7 +30,7 @@ locale.setlocale(locale.LC_NUMERIC, 'C')
class MpvPlayer(PlayerBase):
# The audio is always muted, which is needed because not all the
- # youtube-dl videos are silent. The keep-open flag stops mpv from closing
+ # yt-dlp videos are silent. The keep-open flag stops mpv from closing
# after the video is over.
DEFAULT_FLAGS = ['mute']
DEFAULT_ARGS = {
diff --git a/vidify/player/vlc.py b/vidify/player/vlc.py
index 6a0bec7..a7c9ec0 100644
--- a/vidify/player/vlc.py
+++ b/vidify/player/vlc.py
@@ -31,7 +31,7 @@ class VLCPlayer(PlayerBase):
else:
vlc_args += " --quiet"
# The audio is always muted, which is needed because not all the
- # youtube-dl videos are silent.
+ # yt-dlp videos are silent.
# Needed for the audiosync feature: set the Group of Pictures size to
# one, so that seeking is more precise.
vlc_args += " --no-audio --sout-x264-min-keyint 1"
diff --git a/tests/test_get_lyrics.py b/tests/test_get_lyrics.py
index 5b1bb74..634ca55 100644
--- a/tests/test_get_lyrics.py
+++ b/tests/test_get_lyrics.py
@@ -26,6 +26,6 @@ def test_returnLyricsNotFound():
assert len(responses.calls) == 1
-def test_integration():
- lyrics = get_lyrics('Led Zeppelin', 'Stairway to Heaven')
- assert 'lady' in lyrics.lower()
+# def test_integration():
+# lyrics = get_lyrics('Led Zeppelin', 'Stairway to Heaven')
+# assert 'lady' in lyrics.lower()

View File

@@ -1,48 +0,0 @@
# Copyright 1999-2023 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2
EAPI=7
PYTHON_COMPAT=( python3_{10..11} )
inherit distutils-r1
DESCRIPTION="Python API to get song lyrics from LyricWikia"
HOMEPAGE="https://github.com/enricobacis/lyricwikia"
SRC_URI="https://github.com/enricobacis/${PN}/archive/${PV}.tar.gz -> ${P}.tar.gz"
LICENSE="MIT"
SLOT="0"
KEYWORDS="~amd64"
DEPEND="test? ( dev-python/responses[${PYTHON_USEDEP}] )"
RDEPEND="
dev-python/beautifulsoup4[${PYTHON_USEDEP}]
dev-python/six[${PYTHON_USEDEP}]
dev-python/requests[${PYTHON_USEDEP}]
"
PATCHES="${FILESDIR}/${P}-skip-online-test.patch"
distutils_enable_tests pytest
python_prepare_all() {
# do not depend on deprecated dep
sed -i -e '/pytest-runner/d' setup.py || die
distutils-r1_python_prepare_all
}
python_install_all() {
distutils-r1_python_install_all
# rename the executable to avoid file conflict with net-im/lyrics-in-terminal
find "${D}" -name 'lyrics' -execdir mv {} lyricwikia \; || die
}
pkg_postinst() {
elog "Note that access to LyricWikia through this API (and products that use this API) should comply to the LyricWikia terms of use"
elog ""
elog "LyricWikia is now offline, this package is provided solely for the purpose of satisfying media-video/vidify's dependencies"
}

View File

@@ -1,48 +0,0 @@
# Copyright 1999-2023 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2
EAPI=8
PYTHON_COMPAT=( python3_{10..12} )
DISTUTILS_USE_PEP517=setuptools
inherit distutils-r1
DESCRIPTION="Python API to get song lyrics from LyricWikia"
HOMEPAGE="https://github.com/enricobacis/lyricwikia"
SRC_URI="https://github.com/enricobacis/${PN}/archive/${PV}.tar.gz -> ${P}.tar.gz"
LICENSE="MIT"
SLOT="0"
KEYWORDS="~amd64"
DEPEND="test? ( dev-python/responses[${PYTHON_USEDEP}] )"
RDEPEND="
dev-python/beautifulsoup4[${PYTHON_USEDEP}]
dev-python/six[${PYTHON_USEDEP}]
dev-python/requests[${PYTHON_USEDEP}]
"
PATCHES="${FILESDIR}/${P}-skip-online-test.patch"
distutils_enable_tests pytest
python_prepare_all() {
# do not depend on deprecated dep
sed -i -e '/pytest-runner/d' setup.py || die
distutils-r1_python_prepare_all
}
python_install_all() {
distutils-r1_python_install_all
# rename the executable to avoid file conflict with net-im/lyrics-in-terminal
find "${D}" -name 'lyrics' -execdir mv {} lyricwikia \; || die
}
pkg_postinst() {
elog "Note that access to LyricWikia through this API (and products that use this API) should comply to the LyricWikia terms of use"
elog ""
elog "LyricWikia is now offline, this package is provided solely for the purpose of satisfying media-video/vidify's dependencies"
}

View File

@@ -1,13 +0,0 @@
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE pkgmetadata SYSTEM "https://www.gentoo.org/dtd/metadata.dtd">
<pkgmetadata>
<maintainer type="person">
<email>nowa@gentoo.org</email>
<name>Nowa Ammerlaan</name>
</maintainer>
<stabilize-allarches/>
<upstream>
<remote-id type="github">enricobacis/lyricwikia</remote-id>
</upstream>
</pkgmetadata>

View File

@@ -254,14 +254,6 @@ media-plugins/gst-plugins-kate
# Removal on 2025-03-03 unless upstream fixes the issue
net-im/whatsie
# Nowa Ammerlaan <nowa@gentoo.org> (2025-01-01)
# Broken with Qt6 and in wayland sessions. Archived upstream. Has been on life
# support for several years already.
# Removal on 2025-02-01
media-video/vidify
media-video/vidify-audiosync
net-misc/lyricwikia
# Michał Górny <mgorny@gentoo.org> (2024-12-05)
# 6.12.2 does not boot for me.
=sys-kernel/gentoo-kernel-6.12.2
diff --git a/vidify/youtube.py b/vidify/youtube.py
index 1b23bfb..b959f34 100644
--- a/vidify/youtube.py
+++ b/vidify/youtube.py
@@ -1,5 +1,5 @@
"""
-This module uses youtube-dl to obtain the actual URL of a YouTube link.
+This module uses yt-dlp to obtain the actual URL of a YouTube link.
That way, the video can be played directly with a video player like VLC
or mpv.
"""
@@ -7,7 +7,7 @@ or mpv.
import logging
from typing import Optional
-from youtube_dl import YoutubeDL
+from yt_dlp import YoutubeDL
from qtpy.QtCore import QObject, Signal
@@ -63,7 +63,7 @@ class YouTubeDLWorker(QObject):
def get_url(self) -> None:
"""
Getting the youtube direct link with youtube-dl, intended to be used
with a QThread. It's guaranteed that either a success signal or a
fail signal will be emitted.
"""
@@ -74,13 +74,13 @@ class YouTubeDLWorker(QObject):
except Exception as e:
# Any kind of error has to be caught, so that it doesn't only
# send the error signal when the download wasn't successful
- # (a DownloadError from youtube_dl).
- logging.info("YouTube-dl wasn't able to obtain the video: %s",
+ # (a DownloadError from yt_dlp).
+ logging.info("yt-dlp wasn't able to obtain the video: %s",
str(e))
self.fail.emit()
else:
if len(data['entries']) == 0:
- logging.info("YouTube-dl returned no entries")
+ logging.info("yt-dlp returned no entries")
self.fail.emit()
else:
self.success.emit(data)

View File

@@ -1,24 +0,0 @@
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE pkgmetadata SYSTEM "https://www.gentoo.org/dtd/metadata.dtd">
<pkgmetadata>
<maintainer type="person">
<email>nowa@gentoo.org</email>
<name>Nowa Ammerlaan</name>
</maintainer>
<use>
<flag name="vlc">Use python-vlc as backend for vidify</flag>
<flag name="mpv">Use python-mpv as backend for vidify</flag>
<flag name="zeroconf">Use an external network player</flag>
<flag name="dbus">Support local MPRIS players</flag>
</use>
<upstream>
<maintainer>
<email>marioortizmanero@gmail.com</email>
<name>Mario Ortiz Manero</name>
</maintainer>
<remote-id type="github">vidify/vidify</remote-id>
<bugs-to>https://github.com/vidify/vidify/issues</bugs-to>
</upstream>
<stabilize-allarches/>
</pkgmetadata>

View File

@@ -1,84 +0,0 @@
# Copyright 1999-2024 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2
EAPI=8
PYTHON_COMPAT=( python3_{10..12} )
DISTUTILS_USE_PEP517=setuptools
inherit xdg distutils-r1 optfeature virtualx
DESCRIPTION="Watch music videos in real time for the songs playing on your device"
HOMEPAGE="https://vidify.org"
SRC_URI="https://github.com/${PN}/${PN}/archive/v${PV}.tar.gz -> ${P}.tar.gz"
LICENSE="LGPL-3"
SLOT="0"
KEYWORDS="~amd64"
IUSE="dbus vlc mpv zeroconf"
REQUIRED_USE="|| ( vlc mpv zeroconf )"
RDEPEND="
dev-python/appdirs[${PYTHON_USEDEP}]
dev-python/qtpy[gui,webengine,${PYTHON_USEDEP}]
net-misc/lyricwikia[${PYTHON_USEDEP}]
net-misc/yt-dlp[${PYTHON_USEDEP}]
dbus? ( dev-python/pydbus[${PYTHON_USEDEP}] )
!dbus? ( dev-python/tekore[${PYTHON_USEDEP}] )
mpv? ( dev-python/python-mpv[${PYTHON_USEDEP}] )
vlc? ( dev-python/python-vlc[${PYTHON_USEDEP}] )
zeroconf? ( dev-python/zeroconf[${PYTHON_USEDEP}] )
"
# use yt-dlp instead of youtube-dl, otherwise download is too slow for playback
PATCHES=(
"${FILESDIR}/${P}-yt-dlp.patch"
"${FILESDIR}/${P}-python310.patch"
)
distutils_enable_tests unittest
python_prepare_all() {
# skip online test
rm tests/api/test_spotify_web.py || die
rm tests/player/test_external.py || die
# this needs dbus and a player running
rm tests/api/test_mpris.py || die
# can't parse non-existent config
rm tests/test_api_and_player_data.py || die
# do not hard depend on this
sed -i \
-e '/qdarkstyle/d' \
-e '/python-vlc/d' \
-e '/python-mpv/d' \
-e '/pydbus/d' \
-e '/tekore/d' \
-e '/zeroconf/d' \
-e '/If PySide2 is installed and PyQt5/,/PyQtWebEngine/d' \
setup.py || die
distutils-r1_python_prepare_all
}
python_test() {
virtx "${EPYTHON}" -m unittest discover -v
}
pkg_postinst() {
xdg_pkg_postinst
elog "If video playback is not working please check 'vidify --debug' for missing-codec-errors"
elog "and recompile media-video/vlc or media-video/mpv with the missing codecs"
optfeature "using an MPRIS(D-Bus) audio player (e.g spotify)" dev-python/pydbus
optfeature "using the Spotify Web API as audio player" dev-python/tekore
optfeature "using an external network player" dev-python/zeroconf
optfeature "using media-video/mpv for video playback" dev-python/python-mpv
optfeature "using media-video/vlc for video playback" dev-python/python-vlc
optfeature "'vidify --dark-mode'" dev-python/qdarkstyle
optfeature "'vidify --audiosync'" media-video/vidify-audiosync
}

View File

@@ -1 +0,0 @@
DIST lyricwikia-0.1.11.tar.gz 5571 BLAKE2B 1e2fb5400b4c0ed07d419e577e3c12c6b8eca749ce1a5b7dea51d6d055979722b82d003eac20402da873d3011d1b444c0783935adbc01ec99dd6079b234e6bc7 SHA512 53ff9a2837ccc10be62c2a92240e9849a9c88b7979f8058deff87ce6eda6e98e39fb86c78052de9a885db679cd87a6c5749af2f9502d3316fbbf2c0796718805

View File

@@ -1,14 +0,0 @@
@@ -63,7 +63,7 @@ class YouTubeDLWorker(QObject):
def get_url(self) -> None:
"""
- Getting the youtube direct link with youtube-dl, intended to be used
+ Getting the youtube direct link with yt-dlp, intended to be used
with a QThread. It's guaranteed that either a success signal or a
fail signal will be emitted.